User Guide
==========

Welcome to the LensKit user guide!  These documents provide a topical
guide to how to use LensKit for research, education, and other purposes.

.. toctree::
    :caption: Preliminaries
    :maxdepth: 1

    install
    GettingStarted.ipynb
    examples
    migrating

.. toctree::
    :caption: Fundamentals
    :maxdepth: 1

    principles
    queries
    pipeline

.. toctree::
    :caption: Data
    :maxdepth: 1

    data/index
    data/model
    data/item-lists
    data/datasets

.. toctree::
    :caption: Components
    :maxdepth: 1

    conventions
    flexmf
    scorers
    rankers
    other-components
    implementing

.. toctree::
    :caption: Experiments
    :maxdepth: 1

    splitting
    batch
    evaluation/index
    documenting

.. toctree::
    :caption: Support Code
    :maxdepth: 1

    logging
    parallelism
    ../cli/index
